@@ -7,6 +7,7 @@ Validates markdown documents for:
 - Markdown formatting issues
 - Consistent ADR/RFC numbering
 - MDX compilation compatibility
+- Document readability (Flesch Reading Ease, grade level metrics)
 - Docusaurus build validation
 
 Usage:
@@ -34,6 +35,8 @@ try:
     import yaml
     from pydantic import ValidationError
 
+    from docuchango.readability import TEXTSTAT_AVAILABLE, ReadabilityConfig, ReadabilityScorer
+
     # Import schemas from the docuchango package
     from docuchango.schemas import (
         ADRFrontmatter,
@@ -46,15 +49,24 @@ try:
 
     ENHANCED_VALIDATION = True
 except ImportError as e:
-    print("\n❌ CRITICAL ERROR: Required dependencies not found", file=sys.stderr)
-    print("   Missing: python-frontmatter and/or pydantic", file=sys.stderr)
-    print("   These are REQUIRED for proper frontmatter validation.", file=sys.stderr)
-    print("\n   Fix:", file=sys.stderr)
-    print("   $ uv sync", file=sys.stderr)
-    print("\n   Then run validation with:", file=sys.stderr)
-    print("   $ uv run tooling/validate_docs.py", file=sys.stderr)
-    print(f"\n   Error details: {e}\n", file=sys.stderr)
-    sys.exit(2)
+    # Don't fail if only textstat is missing - just readability features will be disabled
+    if "textstat" in str(e):
+        # textstat is optional - set flag and continue
+        TEXTSTAT_AVAILABLE = False
+        ReadabilityConfig = None  # type: ignore[misc, assignment]
+        ReadabilityScorer = None  # type: ignore[misc, assignment]
+        ENHANCED_VALIDATION = True
+    else:
+        # Critical dependencies missing
+        print("\n❌ CRITICAL ERROR: Required dependencies not found", file=sys.stderr)
+        print("   Missing: python-frontmatter and/or pydantic", file=sys.stderr)
+        print("   These are REQUIRED for proper frontmatter validation.", file=sys.stderr)
+        print("\n   Fix:", file=sys.stderr)
+        print("   $ uv sync", file=sys.stderr)
+        print("\n   Then run validation with:", file=sys.stderr)
+        print("   $ uv run tooling/validate_docs.py", file=sys.stderr)
+        print(f"\n   Error details: {e}\n", file=sys.stderr)
+        sys.exit(2)
 
 
 class LinkType(Enum):
@@ -316,9 +328,9 @@ class DocValidator:
                 )
 
                 for error in e.errors():  # type: ignore[assignment]
-                    field_name = ".".join(str(loc) for loc in error["loc"])  # type: ignore[index]
-                    msg = error["msg"]  # type: ignore[index]
-                    error_type = error["type"]  # type: ignore[index]
+                    field_name = ".".join(str(loc) for loc in error["loc"])
+                    msg = error["msg"]
+                    error_type = error["type"]
 
                     # Format user-friendly error message
                     if error_type == "literal_error":
@@ -858,8 +870,29 @@ class DocValidator:
                     else:
                         # Closing fence
                         if remainder:
-                            # Closing fence has extra text - INVALID
-                            # Per CommonMark: closing fence should have no info string
+                            # Closing fence has extra text - this might indicate an unclosed block earlier
+                            # If the remainder looks like a language specifier (single word, lowercase/numbers),
+                            # this is likely an opening fence that's being misinterpreted as closing
+                            looks_like_language = remainder and " " not in remainder and len(remainder) <= 20
+
+                            if looks_like_language and opening_line:
+                                # Strong signal: unclosed block earlier
+                                error = f"Unclosed code block starting at line {opening_line} (```{opening_language})"
+                                doc.errors.append(error)
+                                self.log(f"   ✗ {doc.file_path.name} - Unclosed block at line {opening_line}")
+                                error = f"Line {line_num}: This appears to be a new opening fence (```{remainder}), but was interpreted as a closing fence due to the unclosed block above"
+                                doc.errors.append(error)
+                                self.log(f"   ℹ {doc.file_path.name}:{line_num} - Cascading error from unclosed block")
+                                doc_invalid_blocks += 2  # Count both errors
+                                total_invalid += 2
+                                # Reset state and treat this as opening fence
+                                in_code_block = True
+                                opening_line = line_num
+                                opening_language = remainder
+                                previous_line_blank = False
+                                continue
+
+                            # Actual closing fence with extra text
                             error = f"Line {line_num}: Closing code fence has extra text (```{remainder}), should be just ```"
                             doc.errors.append(error)
                             self.log(f"   ✗ {doc.file_path.name}:{line_num} - Closing fence with text '```{remainder}'")
@@ -976,6 +1009,39 @@ class DocValidator:
             except Exception as e:
                 doc.errors.append(f"Error checking formatting: {e}")
 
+    def check_readability(self):
+        """Check document readability using textstat metrics."""
+        if not TEXTSTAT_AVAILABLE:
+            self.log("\n📖 Readability checking skipped (textstat not installed)")
+            return
+
+        if not self.project_config or not self.project_config.readability.enabled:
+            self.log("\n📖 Readability checking disabled")
+            return
+
+        self.log("\n📖 Checking readability...")
+
+        # Convert project config to ReadabilityConfig
+        config = self.project_config.readability.to_readability_config()
+
+        scorer = ReadabilityScorer(config)
+
+        for doc in self.documents:
+            try:
+                content = doc.get_content()
+                report = scorer.analyze_document(content, file_path=str(doc.file_path.relative_to(self.repo_root)))
+
+                if report.has_errors():
+                    for line_num, error_msg in report.get_all_errors():
+                        doc.errors.append(f"Line {line_num}: {error_msg}")
+                        self.log(f"   ✗ {doc.file_path.name}:{line_num}: {error_msg}")
+                else:
+                    self.log(f"   ✓ {doc.file_path.name}: {report.total_paragraphs} paragraphs analyzed, all readable")
+
+            except Exception as e:
+                doc.errors.append(f"Error checking readability: {e}")
+                self.log(f"   ✗ {doc.file_path.name}: Readability check failed: {e}")
+
     def check_ids(self):
         """Validate document IDs for consistency and uniqueness"""
         self.log("\n🆔 Checking document IDs...")
@@ -1207,6 +1273,7 @@ class DocValidator:
         self.check_mdx_compatibility()
         self.check_cross_plugin_links()
         self.check_formatting()
+        self.check_readability()  # Check document readability
 
         # Build validation (can be skipped for faster checks)
         build_passed = self.check_typescript_config()
@@ -1242,6 +1309,7 @@ What this checks:
     ✓ Internal link validity
     ✓ MDX syntax compatibility
     ✓ Cross-plugin link issues
+    ✓ Document readability metrics
     ✓ TypeScript compilation
     ✓ Full Docusaurus build
         """,
